Index: runtime/vm/raw_object.h |
diff --git a/runtime/vm/raw_object.h b/runtime/vm/raw_object.h |
index c30823f1ec5cf648e17a2e3ee2a25ee730840404..94b6ee496df063364195805571613368b1cdf63c 100644 |
--- a/runtime/vm/raw_object.h |
+++ b/runtime/vm/raw_object.h |
@@ -1254,7 +1254,7 @@ class RawStackmap : public RawObject { |
// as large as ~33 million entries. If that is sufficient, then these two |
// fields can be merged into a BitField. |
int32_t length_; // Length of payload, in bits. |
- int32_t register_bit_count_; // Live register bits, included in length_. |
+ int32_t slow_path_bit_count_; // Slow path live values, included in length_. |
// Offset from code entry point corresponding to this stack map |
// representation. |